#ifndef _EFL_VG_GRADIENT_EO_H_
#define _EFL_VG_GRADIENT_EO_H_

#ifndef _EFL_VG_GRADIENT_EO_CLASS_TYPE
#define _EFL_VG_GRADIENT_EO_CLASS_TYPE

typedef Eo Efl_VG_Gradient;

#endif

#ifndef _EFL_VG_GRADIENT_EO_TYPES
#define _EFL_VG_GRADIENT_EO_TYPES


#endif
/** Efl vectopr graphics gradient abstract class
 *
 * @ingroup Efl_VG_Gradient
 */
#define EFL_VG_GRADIENT_CLASS efl_vg_gradient_class_get()

EWAPI const Efl_Class *efl_vg_gradient_class_get(void);

#endif
